@@ -3,14 +3,7 @@ require('lualibs')
 tableunpack = table.unpack
 
 ------------------------------------------------------------------------
--- naming:
---    ext_... : called from \directlua{}
---    int_... : called from other Lua codes, but not from \directlua{}
---    (other)     : only called from this file
-function luatexja.load_module(name)
-   require('ltj-' .. name.. '.lua')
-end
-function luatexja.load_lua(fn)
+local function load_lua(fn)
    local found = kpse.find_file(fn, 'tex')
    if not found then
       tex.error("LuaTeX-ja error: File `" .. fn .. "' not found")
@@ -19,6 +12,10 @@ function luatexja.load_lua(fn)
       dofile(found)
    end
 end
+luatexja.load_lua = load_lua
+function luatexja.load_module(name)
+   require('ltj-' .. name.. '.lua')
+end
 
 do
     local setfield = node.direct.setfield
@@ -105,13 +102,14 @@ if luatexja_debug then load_module('debug') end
 load_module('charrange'); local ltjc = luatexja.charrange
 load_module('stack');     local ltjs = luatexja.stack
 load_module('direction'); local ltjd = luatexja.direction -- +1 hlist +1 attr_list
+load_module('lineskip');  local ltjl = luatexja.lineskip -- +1 hlist +1 attr_list
 load_module('jfont');     local ltjf = luatexja.jfont
 load_module('inputbuf');  local ltji = luatexja.inputbuf
 load_module('pretreat');  local ltjp = luatexja.pretreat
 load_module('setwidth');  local ltjw = luatexja.setwidth
 load_module('jfmglue');   local ltjj = luatexja.jfmglue -- +1 glue +1 gs +1 attr_list
 load_module('math');      local ltjm = luatexja.math
-load_module('tangle');    local ltjb = luatexja.base
+load_module('base');      local ltjb = luatexja.base
 
 
 local attr_jchar_class = luatexbase.attributes['ltj@charclass']
